@@ -5,13 +5,16 @@
 """
 
 
-# import degget
-# import games_help
-# import packages
-from degget import show
-from games_help import gen_ru_words
-from packages import install, pip_upgrade, required
+import degget
+import games_help
+import packages
+
+
+# from degget import show
+# from games_help import gen_ru_words
+# from packages import install, pip_upgrade, required
+
 
 __author__ = 'Superior_6564'
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 __email__ = 'vip.klochayil@gmail.com'
